@@ -19,39 +19,33 @@
 HOST = ""
 PORT = 0
 ini = False
-s = None
-_pickle = None
 
-def init(h,p,__pickle):
+
+def init(_host,_port):
 
         global HOST
         global PORT
-        global init
+        global ini
         ini = True
-        global s
-        global _pickle
-        
-        _pickle = __pickle
-        HOST = h
-        PORT = p
+
+        HOST = _host
+        PORT = _port
 
    
     
-def start_server(host,port,debug = False):
+def start_server(debug = False):
 
-            global s
-            global _pickle
-        
-            if s == None:
-                raise RuntimeError("Not initialised. Call remfunc.init(host,port) first.")
+            import pickle, socket
+            global HOST
+		 global PORT
+            if ini == False:
                 
-               
-        
+                raise RuntimeError("Server not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
+            
             if debug == True:
                 print ("Server is Listening.....")
-            HOST = host
-            PORT = port
-            
+           
+            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             s.bind((HOST, PORT))
             s.listen(1)
 
@@ -77,7 +71,7 @@ def start_server(host,port,debug = False):
 
                     data = conn.recv(int(size.decode("utf-8")))
 
-                    code = _pickle.loads(data)
+                    code = pickle.loads(data)
                     block = '\n'.join(code.splitlines()[:-1])
 
                     result = None
@@ -92,9 +86,9 @@ def start_server(host,port,debug = False):
 
 
 
-                    resultsize = str(len(_pickle.dumps(result,-1)))
+                    resultsize = str(len(pickle.dumps(result,-1)))
 
-                    conn.send(_pickle.dumps(resultsize))
+                    conn.send(pickle.dumps(resultsize))
 
                     conn.send(result)
 
@@ -121,18 +115,17 @@ def do(code):
             
            
             
-            
+            import pickle, socket
             global HOST
             global PORT
             global ini
-            global s
-            global _pickle
+           
                 
             if ini == False:
                 
                 raise RuntimeError("Client not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
             
-           
+            s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
             
             try:
                 
@@ -145,7 +138,7 @@ def do(code):
                 
             datatosend = code
             
-            size = str(len(_pickle.dumbs(datatosend,-1)))
+            size = str(len(pickle.dumps(datatosend,-1)))
             
             rsize = None
             result = None
@@ -161,7 +154,7 @@ def do(code):
                 
             try:
                 
-                s.send(_pickle.dumps(datatosend))
+                s.send(pickle.dumps(datatosend))
                 
             except:
                 
@@ -181,7 +174,7 @@ def do(code):
                 
                 try:
                     
-                    result = _pickle.loads(conn.recv(int(rsize.decode("utf-8"))))
+                    result = pickle.loads(conn.recv(int(rsize.decode("utf-8"))))
                     return result
                 
                 except:
@@ -196,3 +189,22 @@ def do(code):
 
 
 
+                
+                
+
+            
+            
+            
+
+
+# In[ ]:
+
+
+
+
+
+# In[ ]:
+
+
+
+
